@@ -681,7 +681,8 @@ static void parseOption(FFdata* data, const char* key, const char* value)
     else if(
         ffOptionsParseGeneralCommandLine(&instance.config.general, key, value) ||
         ffOptionsParseLogoCommandLine(&instance.config.logo, key, value) ||
-        ffOptionsParseDisplayCommandLine(&instance.config.display, key, value)
+        ffOptionsParseDisplayCommandLine(&instance.config.display, key, value) ||
+        ffParseModuleOptions(key, value)
     ) {}
 
     else
