@@ -4,7 +4,7 @@
 
 #define FF_MEMORY_MODULE_NAME "Memory"
 
-void ffPrintMemory(FFMemoryOptions* options);
+bool ffPrintMemory(FFMemoryOptions* options);
 void ffInitMemoryOptions(FFMemoryOptions* options);
 void ffDestroyMemoryOptions(FFMemoryOptions* options);
 
